----------------------------------------------------
-- BasicMap.lua
--
-- Purpose: Generic map script inherited by all other
--	map scripts, for default functionality.
--
-- History:
--	9/22/07 : File created - Kevin Kirst
----------------------------------------------------

BasicMap =
{

};

-- Load default registry
System:ReloadScript("Common/PresetRegistry.lua")

----------------------------------------------------
-- MakeMapScript
--
-- Purpose: Inherit common functionality to
--	make a table a Map Script
--
-- Note: Should be called for all map scripts
------------------------------------------------
function MakeMapScript(map)
	if (not map or type(map) ~= "table") then return end

	-- Merge it in
	CloneTable(map, BasicMap, 1, 1);
end

----------------------------------------------------
-- OnLoaded
--
-- Purpose: Called when the map is loaded
----------------------------------------------------
function BasicMap:OnLoaded()

end

----------------------------------------------------
-- OnUnloaded
--
-- Purpose: Called when the map is unloaded
----------------------------------------------------
function BasicMap:OnUnloaded()

end

----------------------------------------------------
-- OnUpdate
--
-- Purpose: Called periodically
--
-- In:	fdt - Change in time since last call
----------------------------------------------------
function BasicMap:OnUpdate(fdt)

end

----------------------------------------------------
-- OnChat
--
-- Purpose: Called on chat messages
--
-- In:	channel - Chat channel (CHAT_PUBLIC, CHAT_TEAM, CHAT_PRIVATE)
--	team - Team that owns the channel
--	speaker - Player who said the message
--	message - The actual message
----------------------------------------------------
function BasicMap:OnChat(channel, team, speaker, message)
	
end

----------------------------------------------------
-- OnCommand
--
-- Purpose: Called when a command is issued
--	via chat
--
-- In:	player - Player who issued the command
--	command - Command that was issued
--	args - Arguments for the command, in array format
--	channel - Where command was issued
--	team - Team that owns the channel
----------------------------------------------------
function BasicMap:OnCommand(player, command, args, channel, team)
	-- Get player name
	local playername = "No Name";
	if (player) then playername = player:GetName(); end

	-- Test response
	if (command == "say") then
		if (not args) then
			Commands:Console_Input("msg I don't know what to say!");
		else
			Commands:Console_Input("msg " .. playername .. " told me to say " .. args[1]);
		end
	end

	-- Kill command
	if (command == "killme" and player) then player:Kill(); end
end

----------------------------------------------------
-- OnHostMessage
--
-- Purpose: Called when a host message occurs
--
-- In:	channel - Chat channel
--	message - What was said
----------------------------------------------------
function BasicMap:OnHostMessage(channel, message)
	
end

----------------------------------------------------
-- OnPurchase
--
-- Purpose: Called when a player makes a purchase
--
-- In:	player - Who made the purchase
--	cost - How much it cost
--	preset - What they bought
----------------------------------------------------
function BasicMap:OnPurchase(player, cost, preset)

end