----------------------------------------------------
-- main.lua
--
-- Purpose: Script main entry point
--
-- History:
--	9/22/07 : File created - Kevin Kirst
----------------------------------------------------

function main()
	Commands:Console_Output("Script System running with no ill effects");
end


----------------------------------------------------
-- CloneTable
--
-- Purpose: Merges a table into another one
--
-- In:	dest - Destination table
--	src - Source table (to clone)
--	rec - Pass in to merge children tables as well
--	skip - Pass in to skip what is already in the table
----------------------------------------------------
function CloneTable(dest, src, rec, skip)
	-- Iterate through
	for i,v in pairs(src) do
		-- If skipping, make sure we don't already have this
		if (not skip or (skip and not dest[i])) then
			-- If table and recursive, then clone child too
			if (rec and type(v) == "table") then
				dest[i] = {};
				CloneTable(dest[i], v, rec, skip);
			else
				dest[i] = v;
			end
		end
	end
end

----------------------------------------------------
-- GetTeamName
--
-- Purpose: Get the name of the team by its id
--
-- In:	teamid - Team ID
----------------------------------------------------
function GetTeamName(teamid)
	if (teamid == TEAM_GDI) then return "GDI" end
	if (teamid == TEAM_NOD) then return "Nod" end
	return "Unknown";
end

----------------------------------------------------
-- ArgumentsToString
--
-- Purpose: Convert an array of arguments into a string
--
-- In:	args - Table of arguments in array format
--
-- Returns string format or nil if no arguments
----------------------------------------------------
function ArgumentsToString(args)
	local argstr = nil;

	-- Cycle through
	if (args) then
		for i,arg in ipairs(args) do
			if (not argstr) then
				argstr = "";
			else
				argstr = argstr .. " ";
			end
			argstr = argstr .. arg;
		end
	end
	
	-- Final check
	return argstr;
end