////////////////////////////////////////////////////
// CObjectManager.cpp
//
// Purpose: Monitors object creations and attatched
//	Lua scripts to them
//
// File History:
//	- 8/13/07 : File created - Kevin Kirst
////////////////////////////////////////////////////

#include "CObjectManager.h"
#include "engine.h"
#include "gmmain.h"
#include "CLuaEngineManager.h"

CObjectManager CObjectManager::m_Instance;
CObjectManager* ObjectManager = &CObjectManager::GetInstance();

////////////////////////////////////////////////////
CObjectManager::CObjectManager(void)
{
	m_nObjectHookID = -1;
	m_pObjectHook = NULL;
	m_nPlayerPurchaseHookID = -1;
	m_nVehiclePurchaseHookID = -1;
	m_nPowerupPurchaseHookID = -1;
}

////////////////////////////////////////////////////
CObjectManager::~CObjectManager(void)
{

}

////////////////////////////////////////////////////
CObjectManager& CObjectManager::GetInstance(void)
{
	return m_Instance;
}

////////////////////////////////////////////////////
void CObjectManager::CreateHook(void)
{
	// Must not have alredy been created
	if (NULL == m_pObjectHook)
	{
		// Create the hook
		m_pObjectHook = new ObjectCreateHookStruct;
		m_pObjectHook->hook = CObjectManager::OnObjectCreated;
		m_pObjectHook->data = this;
		m_nObjectHookID = AddObjectCreateHook(m_pObjectHook);
	}

	// Create purchase hooks if we don't have them either
	if (-1 == m_nPlayerPurchaseHookID)
		m_nPlayerPurchaseHookID = AddCharacterPurchaseMonHook(CObjectManager::OnPurchase, (char const*)this);
	if (-1 == m_nVehiclePurchaseHookID)
		m_nVehiclePurchaseHookID = AddVehiclePurchaseMonHook(CObjectManager::OnPurchase, (char const*)this);
	if (-1 == m_nPowerupPurchaseHookID)
		m_nPowerupPurchaseHookID = AddPowerupPurchaseMonHook(CObjectManager::OnPurchase, (char const*)this);
}

////////////////////////////////////////////////////
void CObjectManager::DestroyHook(void)
{
	// Destroy it
	if (NULL != m_pObjectHook)
	{
		RemoveObjectCreateHook(m_nObjectHookID);
		delete m_pObjectHook;
		m_pObjectHook = NULL;
		m_nObjectHookID = 0;
	}

	// Remove purchase hooks
	if (-1 != m_nPlayerPurchaseHookID)
		RemoveCharacterPurchaseMonHook(m_nPlayerPurchaseHookID);
	if (-1 != m_nVehiclePurchaseHookID)
		RemoveCharacterPurchaseMonHook(m_nVehiclePurchaseHookID);
	if (-1 != m_nPowerupPurchaseHookID)
		RemoveCharacterPurchaseMonHook(m_nPowerupPurchaseHookID);
}

////////////////////////////////////////////////////
void CObjectManager::OnObjectCreated(void *pThis, GameObject *pObj)
{
	if (NULL == pThis || NULL == pObj) return;

	// Get manager
	//CObjectManager *pManager = (CObjectManager*)pThis;

	printf("%s\n", Commands->Get_Preset_Name(pObj));

	// Load the object's script
	LuaManager->OnObjectCreated(pObj);
}

////////////////////////////////////////////////////
void CObjectManager::OnPurchase(BaseControllerClass *pController, GameObject *pPurchaser, 
		unsigned int nCost, unsigned int nPreset, unsigned int nPurchaseRet, 
		const char *pThis)
{
	if (NULL == pThis || NULL == pController || NULL == pPurchaser) return;

	// Check cost against player pending nPurchaseRet's value, whatever that means
	if (0 != nPurchaseRet && Commands->Get_Money(pPurchaser) < nCost) return;

	// Inform Lua Manager
	LuaManager->OnPurchase(pPurchaser, nCost, nPreset);
}