////////////////////////////////////////////////////
// CObjectManager.h
//
// Purpose: Monitors object creations and attatched
//	Lua scripts to them
//
// File History:
//	- 8/13/07 : File created - Kevin Kirst
////////////////////////////////////////////////////

#ifndef _COBJECTMANAGER_H_
#define _COBJECTMANAGER_H_

#include "scripts.h"
#include "engine.h"

struct ObjectCreateHookStruct;

////////////////////////////////////////////////////
class CObjectManager
{
	// Object hook info
	int m_nObjectHookID;
	int m_nPlayerPurchaseHookID;
	int m_nVehiclePurchaseHookID;
	int m_nPowerupPurchaseHookID;
	ObjectCreateHookStruct *m_pObjectHook;

	////////////////////////////////////////////////////
	// Constructor
	////////////////////////////////////////////////////
	CObjectManager(void);
	CObjectManager(CObjectManager const&) {}
	CObjectManager& operator =(CObjectManager const&) {return *this;}

	// Single instance
	static CObjectManager m_Instance;

	////////////////////////////////////////////////////
	// OnObjectCreated
	//
	// Purpose: Called when an object has been created
	//
	// In:	pThis - Instance of object manager
	//		pObj - Object that was created
	////////////////////////////////////////////////////
	static void OnObjectCreated(void *pThis, GameObject *pObj);

	////////////////////////////////////////////////////
	// OnPurchase
	//
	// Purpose: Called when a purchase is made
	//
	// In:	pController - Base Controller object
	//		pPurchaser - Who made the purchase
	//		nCost - How much it cost
	//		nPreset - ID of preset that was bought
	//		nPurchaseRet - ?
	//		pThis - Instance of object manager
	////////////////////////////////////////////////////
	static void OnPurchase(BaseControllerClass *pController, GameObject *pPurchaser, 
		unsigned int nCost, unsigned int nPreset, unsigned int nPurchaseRet, 
		const char *pThis);

public:
	////////////////////////////////////////////////////
	// Destructor
	////////////////////////////////////////////////////
	virtual ~CObjectManager(void);

	////////////////////////////////////////////////////
	// GetInstance
	//
	// Purpose: Return single instance of class
	////////////////////////////////////////////////////
	static CObjectManager& GetInstance(void);

	////////////////////////////////////////////////////
	// CreateHook
	//
	// Purpose: Create the hook
	////////////////////////////////////////////////////
	void CreateHook(void);

	////////////////////////////////////////////////////
	// DestroyHook
	//
	// Purpose: Destroy the hoook
	////////////////////////////////////////////////////
	void DestroyHook(void);
};

extern CObjectManager* ObjectManager;

#endif //_COBJECTMANAGER_H_