////////////////////////////////////////////////////
// CScriptObjectCommands.cpp
//
// Purpose: Scriptable object to wrap around commands
//
// File History:
//	- 8/13/07 : File created - Kevin Kirst
////////////////////////////////////////////////////

#include "CScriptObjectCommands.h"
#include "scripts.h"
#include "engine.h"
#include "plugin.h"

MAKE_SCRIPTABLE(CScriptObjectCommands);

//////////////////////////////////////////////////////
CScriptObjectCommands::CScriptObjectCommands(IScriptSystem *pSS)
{
	Init(pSS, "Commands", this, false);
}

//////////////////////////////////////////////////////
CScriptObjectCommands::~CScriptObjectCommands(void)
{

}

//////////////////////////////////////////////////////
void CScriptObjectCommands::InitializeTemplate(IScriptSystem *pSS)
{
	IScriptableClass<CScriptObjectCommands>::InitializeTemplate(pSS, "Commands");

	// Globals
	// Teams
	pSS->SetGlobal("TEAM_GDI", TEAM_GDI);
	pSS->SetGlobal("TEAM_NOD", TEAM_NOD);
	// Chat types
	pSS->SetGlobal("CHAT_PUBLIC", CHAT_PUBLIC);
	pSS->SetGlobal("CHAT_TEAM", CHAT_TEAM);
	pSS->SetGlobal("CHAT_PRIVATE", CHAT_PRIVATE);

	// Register functions
	RegisterFunction("Console_Output", &Console_Output);
	RegisterFunction("Console_Input", &Console_Input);
}

//////////////////////////////////////////////////////
int CScriptObjectCommands::Console_Output(IFunctionHandler *pH)
{
	CHECK_ARGUMENTS(1);
	CHECK_ARGUMENT_TYPE(1, luaString);

	// Get it
	std::string szMsg;
	pH->GetArgument(1, szMsg);

	// Forward
	::Console_Output(szMsg.c_str());
	::Console_Output("\n");
	return pH->EndFunctionNull();
}

//////////////////////////////////////////////////////
int CScriptObjectCommands::Console_Input(IFunctionHandler *pH)
{
	CHECK_ARGUMENTS(1);
	CHECK_ARGUMENT_TYPE(1, luaString);

	// Get it
	std::string szCommand;
	pH->GetArgument(1, szCommand);

	// Forward
	::Console_Input(szCommand.c_str());
	return pH->EndFunctionNull();
}