////////////////////////////////////////////////////
// CScriptObjectLevel.cpp
//
// Purpose: Scriptable object to wrap around a level
//	script
//
// File History:
//	- 8/13/07 : File created - Kevin Kirst
////////////////////////////////////////////////////

#include "CScriptObjectLevel.h"
#include "scripts.h"
#include "engine.h"
#include "plugin.h"

MAKE_SCRIPTABLE(CScriptObjectLevel);

//////////////////////////////////////////////////////
CScriptObjectLevel::CScriptObjectLevel()
{
	
}

//////////////////////////////////////////////////////
CScriptObjectLevel::~CScriptObjectLevel(void)
{

}

//////////////////////////////////////////////////////
void CScriptObjectLevel::InitializeTemplate(IScriptSystem *pSS)
{
	IScriptableClass<CScriptObjectLevel>::InitializeTemplate(pSS, "_TEMP_LEVEL");

	// Register functions
	RegisterFunction("EndLevel", &EndLevel);
}

//////////////////////////////////////////////////////
void CScriptObjectLevel::SetLevel(IScriptSystem *pSS, char const* szLevel)
{
	// Init it
	Init(pSS, szLevel, this, true);
	m_szLevel = szLevel;
}

//////////////////////////////////////////////////////
void CScriptObjectLevel::OnTick(float fdt)
{
	// If there is a map script loaded, update it
	if (true == m_pSS->BeginCall(m_szLevel.c_str(), "OnUpdate"))
	{
		m_pSS->PushArgument(GetScriptObject());
		m_pSS->PushArgument(fdt);
		m_pSS->EndCall();
	}
}

//////////////////////////////////////////////////////
int CScriptObjectLevel::EndLevel(IFunctionHandler *pH)
{
	// Check argument
	if (pH->GetArgumentCount() > 0 && pH->GetArgumentType(1) == luaNumber)
	{
		// Get winning team ID
		int nTeam;
		pH->GetArgument(1, nTeam);

		// If not GDI or Nod, raise error
		if (nTeam != TEAM_GDI && nTeam != TEAM_NOD)
		{
			GetScriptSystem()->RaiseError("CScriptObjectLevel::EndLevel invalid team specified for argument 1");
			return pH->EndFunctionNull();
		}

		// Kill opposite team's buildings
		Kill_All_Buildings_By_Team(nTeam==TEAM_GDI?TEAM_NOD:TEAM_GDI);
		return pH->EndFunctionNull();
	}

	// If no team is specified, just gameover it
	Console_Input("gameover");
	return pH->EndFunctionNull();
}