////////////////////////////////////////////////////
// CScriptObjectLevel.h
//
// Purpose: Scriptable object to wrap around a level
//	script
//
// File History:
//	- 8/13/07 : File created - Kevin Kirst
////////////////////////////////////////////////////

#ifndef _CSCRIPTOBJECT_LEVEL_H_
#define _CSCRIPTOBJECT_LEVEL_H_

#include "CLuaEngineManager.h"

class CScriptObjectLevel : public IScriptableClass<CScriptObjectLevel>
{
	// Currently loaded level
	std::string m_szLevel;

public:
	//////////////////////////////////////////////////////
	// Constructor
	//////////////////////////////////////////////////////
	CScriptObjectLevel(void);
private:
	CScriptObjectLevel(CScriptObjectLevel const&) {}
	CScriptObjectLevel& operator =(CScriptObjectLevel const&) {return *this;}

public:
	//////////////////////////////////////////////////////
	// Destructor
	//////////////////////////////////////////////////////
	virtual ~CScriptObjectLevel(void);

	//////////////////////////////////////////////////////
	static void InitializeTemplate(IScriptSystem *pSS);

	//////////////////////////////////////////////////////
	// SetLevel
	//
	// Purpose: Load the level script and attach yourself
	//	to it
	//
	// In:	pScriptSystem - Script system
	//		szLevel - Path to level script
	//////////////////////////////////////////////////////
	void SetLevel(IScriptSystem *pSS, char const* szLevel);

	//////////////////////////////////////////////////////
	// OnTick
	//
	// Purpose: Called on tick to notify OnUpdate
	//
	// In:	fdt - Change in time since last call
	//////////////////////////////////////////////////////
	void OnTick(float fdt);

public:
	//////////////////////////////////////////////////////
	// EndLevel
	//
	// Purpose: End the current level by calling a gameover
	//
	// In:	nWinningTeam - (Number, Optional) If specified,
	//			this team is declared the winner.
	//
	// Note: Only TEAM_GDI and TEAM_NOD are valid teams
	//////////////////////////////////////////////////////
	int EndLevel(IFunctionHandler *pH);
};

#endif //_CSCRIPTOBJECT_LEVEL_H_