////////////////////////////////////////////////////
// CScriptObjectPlayer.cpp
//
// Purpose: Scriptable object to wrap around a player
//	script
//
// File History:
//	- 8/22/07 : File created - Kevin Kirst
////////////////////////////////////////////////////

#include "CScriptObjectPlayer.h"
#include "scripts.h"
#include "engine.h"
#include "plugin.h"

MAKE_SCRIPTABLE(CScriptObjectPlayer);

//////////////////////////////////////////////////////
CScriptObjectPlayer::CScriptObjectPlayer()
{
	m_nPlayerID = -1;
	m_nLastPresetID = -1;
}

//////////////////////////////////////////////////////
CScriptObjectPlayer::~CScriptObjectPlayer(void)
{

}

//////////////////////////////////////////////////////
void CScriptObjectPlayer::InitializeTemplate(IScriptSystem *pSS)
{
	IScriptableClass<CScriptObjectPlayer>::InitializeTemplate(pSS, "_TEMP_PLAYER");

	// Register functions
	RegisterFunction("GetID", &GetID);
	RegisterFunction("GetName", &GetName);
	RegisterFunction("Kill", &Kill);
}

//////////////////////////////////////////////////////
void CScriptObjectPlayer::SetPlayer(IScriptSystem *pSS, int nID)
{
	// Init it
	Init(pSS, "Player", this, true);

	m_nPlayerID = nID;
}

//////////////////////////////////////////////////////
void CScriptObjectPlayer::OnTick(float fdt)
{
	// Update player
	if (true == m_pSS->BeginCall("Player", "OnUpdate"))
	{
		m_pSS->PushArgument(GetScriptObject());
		m_pSS->PushArgument(fdt);
		m_pSS->EndCall();
	}

	// Look for preset change
	GameObject *pPlayer = Get_GameObj(m_nPlayerID);
	if (NULL != pPlayer)
	{
		int nPresetID = Commands->Get_Preset_ID(pPlayer);
		int nLastID = m_nLastPresetID;
		m_nLastPresetID = nPresetID;

		// Check against it
		if (nLastID != nPresetID)
		{
			// Notify script
			if (true == m_pSS->BeginCall("Player", "OnPresetChange"))
			{
				m_pSS->PushArgument(GetScriptObject());
				m_pSS->PushArgument(Get_Definition_Name(nPresetID));
				if (nLastID == -1)
					m_pSS->PushNullArgument();
				else
					m_pSS->PushArgument(Get_Definition_Name(nLastID));

				// Check return
				int nRet = 0;
				m_pSS->EndCall(nRet);
				if (1 == nRet && nLastID != -1)
				{
					// Convert back
					Change_Character(pPlayer, Get_Definition_Name(nLastID));
				}
			}
		}
	}
}

//////////////////////////////////////////////////////
int CScriptObjectPlayer::GetID(IFunctionHandler *pH)
{
	// Must be attached
	if (-1 == m_nPlayerID)
		return pH->EndFunctionNull();

	return pH->EndFunction(m_nPlayerID);
}

//////////////////////////////////////////////////////
int CScriptObjectPlayer::GetName(IFunctionHandler *pH)
{
	// Must be attached
	if (-1 == m_nPlayerID)
		return pH->EndFunctionNull();

	return pH->EndFunction(Get_Player_Name_By_ID(m_nPlayerID));
}

//////////////////////////////////////////////////////
int CScriptObjectPlayer::Kill(IFunctionHandler *pH)
{
	// Must be attached
	if (-1 == m_nPlayerID)
		return pH->EndFunctionNull();

	// Kill the player
	GameObject *pObj = Get_GameObj(m_nPlayerID);
	if (NULL == pObj)
		return pH->EndFunctionNull();
	Commands->Apply_Damage(pObj, 99999.0f, "Explosive", 0);
	return pH->EndFunction(1);
}