////////////////////////////////////////////////////
// CScriptObjectPlayer.h
//
// Purpose: Scriptable object to wrap around a player
//	script
//
// File History:
//	- 8/22/07 : File created - Kevin Kirst
////////////////////////////////////////////////////

#ifndef _CSCRIPTOBJECT_PLAYER_H_
#define _CSCRIPTOBJECT_PLAYER_H_

#include "CLuaEngineManager.h"

class CScriptObjectPlayer : public IScriptableClass<CScriptObjectPlayer>
{
	// Attached player ID
	int m_nPlayerID;

	// Last known preset
	int m_nLastPresetID;

public:
	//////////////////////////////////////////////////////
	// Constructor
	//////////////////////////////////////////////////////
	CScriptObjectPlayer(void);
private:
	CScriptObjectPlayer(CScriptObjectPlayer const&) {}
	CScriptObjectPlayer& operator =(CScriptObjectPlayer const&) {return *this;}

public:
	//////////////////////////////////////////////////////
	// Destructor
	//////////////////////////////////////////////////////
	virtual ~CScriptObjectPlayer(void);

	//////////////////////////////////////////////////////
	static void InitializeTemplate(IScriptSystem *pSS);

	//////////////////////////////////////////////////////
	// SetPlayer
	//
	// Purpose: Attach yourself to the player with the
	//	given ID
	//
	// In:	pScriptSystem - Script system
	//		nID - Player ID
	//////////////////////////////////////////////////////
	void SetPlayer(IScriptSystem *pSS, int nID);

	//////////////////////////////////////////////////////
	// OnTick
	//
	// Purpose: Called on tick to notify OnUpdate
	//
	// In:	fdt - Change in time since last call
	//////////////////////////////////////////////////////
	void OnTick(float fdt);

public:
	//////////////////////////////////////////////////////
	// GetID
	//
	// Purpose: Returns the player's ID
	//////////////////////////////////////////////////////
	int GetID(IFunctionHandler *pH);

	//////////////////////////////////////////////////////
	// GetName
	//
	// Purpose: Returns the player's name
	//////////////////////////////////////////////////////
	int GetName(IFunctionHandler *pH);

	//////////////////////////////////////////////////////
	// Kill
	//
	// Purpose: Kill the player!
	//////////////////////////////////////////////////////
	int Kill(IFunctionHandler *pH);
};

#endif //_CSCRIPTOBJECT_LEVEL_H_