////////////////////////////////////////////////////
// CScriptObjectSystem.cpp
//
// Purpose: Scriptable object to wrap around
//	system-specific calls, such as loading scripts
//
// File History:
//	- 8/22/07 : File created - Kevin Kirst
////////////////////////////////////////////////////

#include "CScriptObjectSystem.h"
#include "scripts.h"
#include "engine.h"
#include "plugin.h"

MAKE_SCRIPTABLE(CScriptObjectSystem);

//////////////////////////////////////////////////////
CScriptObjectSystem::CScriptObjectSystem(IScriptSystem *pSS)
{
	Init(pSS, "System", this, false);
}

//////////////////////////////////////////////////////
CScriptObjectSystem::~CScriptObjectSystem(void)
{

}

//////////////////////////////////////////////////////
void CScriptObjectSystem::InitializeTemplate(IScriptSystem *pSS)
{
	IScriptableClass<CScriptObjectSystem>::InitializeTemplate(pSS, "System");

	// Register functions
	RegisterFunction("LoadScript", &LoadScript);
	RegisterFunction("ReloadScript", &ReloadScript);
	RegisterFunction("Error", &Error);
}

//////////////////////////////////////////////////////
int CScriptObjectSystem::LoadScript(IFunctionHandler *pH)
{
	CHECK_ARGUMENTS(1);
	CHECK_ARGUMENT_TYPE(1, luaString);

	// Get script file
	std::string szFile;
	pH->GetArgument(1, szFile);
	szFile = std::string(SCRIPT_PATH_BASE) + szFile;

	// Load it
	if (true == m_pSS->LoadScript(szFile.c_str()))
		return pH->EndFunction(1);
	return pH->EndFunctionNull();
}

//////////////////////////////////////////////////////
int CScriptObjectSystem::ReloadScript(IFunctionHandler *pH)
{
	CHECK_ARGUMENTS(1);
	CHECK_ARGUMENT_TYPE(1, luaString);

	// Get script file
	std::string szFile;
	pH->GetArgument(1, szFile);
	szFile = std::string(SCRIPT_PATH_BASE) + szFile;

	// Load it
	if (true == m_pSS->ReloadScript(szFile.c_str()))
		return pH->EndFunction(1);
	return pH->EndFunctionNull();
}

//////////////////////////////////////////////////////
int CScriptObjectSystem::Error(IFunctionHandler *pH)
{
	std::string szReason = "Manual error raised.";
	if (pH->GetArgumentCount() > 0 && pH->GetArgumentType(1) == luaString)
		pH->GetArgument(1, szReason);

	// Raise error
	m_pSS->RaiseError(szReason.c_str());
	return pH->EndFunctionNull();
}