////////////////////////////////////////////////////
// CScriptObjectSystem.h
//
// Purpose: Scriptable object to wrap around
//	system-specific calls, such as loading scripts
//
// File History:
//	- 8/22/07 : File created - Kevin Kirst
////////////////////////////////////////////////////

#ifndef _CSCRIPTOBJECT_SYSTEM_H_
#define _CSCRIPTOBJECT_SYSTEM_H_

#include "CLuaEngineManager.h"

class CScriptObjectSystem : public IScriptableClass<CScriptObjectSystem>
{
public:
	//////////////////////////////////////////////////////
	// Constructor
	//////////////////////////////////////////////////////
	CScriptObjectSystem(IScriptSystem *pSS);
private:
	CScriptObjectSystem(CScriptObjectSystem const&) {}
	CScriptObjectSystem& operator =(CScriptObjectSystem const&) {return *this;}

public:
	//////////////////////////////////////////////////////
	// Destructor
	//////////////////////////////////////////////////////
	virtual ~CScriptObjectSystem(void);

	//////////////////////////////////////////////////////
	static void InitializeTemplate(IScriptSystem *pSS);

public:
	//////////////////////////////////////////////////////
	// LoadScript
	//
	// Purpose: Loads a script into the system
	//
	// In:	szFile - (String) Script file to load, relative
	//			to the Scripts folder
	//
	// Returns nil if script failed to load
	//////////////////////////////////////////////////////
	int LoadScript(IFunctionHandler *pH);

	//////////////////////////////////////////////////////
	// ReloadScript
	//
	// Purpose: Reloads a script into the system
	//
	// In:	szFile - (String) Script file to reload, relative
	//			to the Scripts folder
	//
	// Returns nil if script failed to load
	//////////////////////////////////////////////////////
	int ReloadScript(IFunctionHandler *pH);

	//////////////////////////////////////////////////////
	// Error
	//
	// Purpose: Raise a manual script error
	//
	// In:	szReason - (String, optional) Reason for the
	//			error
	//////////////////////////////////////////////////////
	int Error(IFunctionHandler *pH);
};

#endif //_CSCRIPTOBJECT_COMMANDS_H_