//////////////////////////////////////////////////////
// IFunctionHandler.h
//
// Purpose: Interface object
//	Describes a helper used for Lua->C functions
//
// History:
//	- 5/17/07 : File created - Kevin Kirst
//////////////////////////////////////////////////////

#ifndef _IFUNCTIONHANDLER_H_
#define _IFUNCTIONHANDLER_H_

#include "IScriptSystem.h"

struct IFunctionHandler
{
	//////////////////////////////////////////////////////
	// Destructor
	//////////////////////////////////////////////////////
	virtual ~IFunctionHandler(void) {}

	//////////////////////////////////////////////////////
	// _Attach
	//
	// Purpose: Internal use - attach handler to owner
	//////////////////////////////////////////////////////
	virtual void _Attach(lua_State *pState) = 0;

	//////////////////////////////////////////////////////
	// GetArgumentCount
	//
	// Purpose: Returns number of arguments
	//////////////////////////////////////////////////////
	virtual int GetArgumentCount(void) = 0;

	//////////////////////////////////////////////////////
	// GetArgument
	//
	// Purpose: Returns the given argument
	//
	// In:	index - Index of argument
	//		out - Where to store the argument
	//
	// Returns: TRUE if argument was retrieved
	//
	// Note: Syntax sugar should always be used when calling
	//	the function.  Therefore, index '1' is the first
	//	argument following 'self' (really at location 2)
	//////////////////////////////////////////////////////
	virtual bool GetArgument(int index, int &out) = 0;
	virtual bool GetArgument(int index, size_t &out) = 0;
	virtual bool GetArgument(int index, float &out) = 0;
	virtual bool GetArgument(int index, bool &out) = 0;
	virtual bool GetArgument(int index, char*out, int len) = 0;
	virtual bool GetArgument(int index, std::string &out) = 0;
	virtual bool GetArgument(int index, IScriptObject *out) = 0;

	//////////////////////////////////////////////////////
	// GetArgumentType
	//
	// Purpose: Returns type of argument
	//
	// In:	index - Index of argument
	//////////////////////////////////////////////////////
	virtual VarType GetArgumentType(int index) = 0;

	//////////////////////////////////////////////////////
	// EndFunction
	//
	// Purpose: Ends the function and returns execution
	//	to the Lua script
	//
	// In:	ret - Return value
	//
	// Note: Always return from the C function with this
	//	call!  The return value is used by Lua
	//////////////////////////////////////////////////////
	virtual int EndFunctionNull() = 0;
	virtual int EndFunction(int ret) = 0;
	virtual int EndFunction(size_t ret) = 0;
	virtual int EndFunction(int ret, int ret2) = 0;
	virtual int EndFunction(float ret) = 0;
	virtual int EndFunction(float ret, float ret2) = 0;
	virtual int EndFunction(bool ret) = 0;
	virtual int EndFunction(char const* ret) = 0;
	virtual int EndFunction(IScriptObject *ret, bool bReleaseTable = false) = 0;
};

#endif //_IFUNCTIONHANDLER_H_