////////////////////////////////////////////////////
// LuaEngine.h
//
// Purpose: Master include file
//	Brings in all objects and defines DLL exports
//
// File History:
//	- 8/12/07 : File created - Kevin Kirst
////////////////////////////////////////////////////

#ifndef _LUAENGINE_H_
#define _LUAENGINE_H_

// STL usage
#include <string>
#include <vector>
#include <map>

// Lua includes
extern "C" {
	#include "Lua/lua.h"
	#include "Lua/lualib.h"
	#include "Lua/lauxlib.h"
}

// Engine interfaces
#include "IScriptSystem.h"			// Main system
#include "IScriptObject.h"			// Table wrapper
#include "IScriptVar.h"				// Global variable wrapper
#include "IScriptableClass.h"		// Class exposure
#include "IFunctionHandler.h"		// C-Function helper

////////////////////////////////////////////////////
////////////////////////////////////////////////////

////////////////////////////////////////////////////
#ifdef LUAENGINE_EXPORTS
	#define LUAENGINE_API __declspec(dllexport)
#else
	#define LUAENGINE_API __declspec(dllimport)
#endif
////////////////////////////////////////////////////

////////////////////////////////////////////////////
// GetScriptSystem
//
// Purpose: Returns a reference to the script system
////////////////////////////////////////////////////
LUAENGINE_API IScriptSystem* GetScriptSystem(void);

////////////////////////////////////////////////////
// ReleaseScriptSystem
//
// Purpose: Release an instance of the script system
//
// In:	pSS - Script system to release
////////////////////////////////////////////////////
LUAENGINE_API void ReleaseScriptSystem(IScriptSystem *pSS);

////////////////////////////////////////////////////
// CreateScriptObject
//
// Purpose: Creates and returns an empy script object
////////////////////////////////////////////////////
LUAENGINE_API IScriptObject* CreateRawScriptObject(void);

////////////////////////////////////////////////////
// CreateScriptVar
//
// Purpose: Creates and returns an empty script variable
////////////////////////////////////////////////////
LUAENGINE_API IScriptVar* CreateScriptVar(void);

////////////////////////////////////////////////////
// SetErrorCallback
//
// Purpose: Set the callback function to use for
//	error forwarding
//
// In:	pFunc - Function to call (see LUAENGINE_ERRORCALLBACK)
////////////////////////////////////////////////////
LUAENGINE_API void SetErrorCallback(LUAENGINE_ERRORCALLBACK pFunc);


#endif //_LUAENGINE_H_