/*	Renegade Scripts.dll
	Example Plugin Code
	Copyright 2007 Whitedragon(MDB), Jonathan Wilson

	This file is part of the Renegade scripts.dll
	The Renegade scripts.dll is free software; you can redistribute it and/or modify it under
	the terms of the GNU General Public License as published by the Free
	Software Foundation; either version 2, or (at your option) any later
	version. See the file COPYING for more details.
	In addition, an exemption is given to allow Run Time Dynamic Linking of this code with any closed source module that does not contain code covered by this licence.
	Only the source code to the module(s) containing the licenced code has to be released.
*/

/*  This is designed to serve as both an example on how to make a plugin and to give users the basic framework of a plugin.
    The plugin is simple: it creates an object creation hook and attaches the script "Plugin_Example_Script" to all objects.
	The script prints out a message whenever an object is created or destroyed.
	There are also examples of the new format for bhs.dll hooks.
*/

////////////////////////////////////////////////////
// Copyright (C), RenEvo Studios, 2007
//
// plugin.cpp
//
// Purpose: Plug-in entry point
//
// File History:
//	- 8/13/07 : File created - Kevin Kirst
////////////////////////////////////////////////////

#include "scripts.h"
#include "engine.h"
#include "gmmain.h"
#include "plugin.h"

// Plug-in Includes
#include "CLuaEngineManager.h"
#include "CObjectManager.h"

////////////////////////////////////////////////////
void Plugin_Load(void)
{
	// Create object hook
	ObjectManager->CreateHook();

	// Init Lua manager
	LuaManager->Initialize();

	// Execute main call
	Lua->LoadScript("Data\\Scripts\\main.lua");
	if (true == Lua->BeginCall("main"))
	{
		Lua->EndCall();
	}
}

////////////////////////////////////////////////////
void Plugin_Unload(void)
{
	// Destroy object hook
	ObjectManager->DestroyHook();
}

////////////////////////////////////////////////////
////////////////////////////////////////////////////


extern "C"
{
	DLLEXPORT void SSGM_Chat_Hook(int ID, int Type, const wchar_t *Msg)
	{
		LuaManager->OnChatMessage(ID, Type, WideCharToString(Msg).c_str());
	}

	DLLEXPORT void SSGM_Host_Hook(int ID, int Type, const char *Msg)
	{
		LuaManager->OnHostMessage(Type, Msg);
	}

	DLLEXPORT void SSGM_Player_Join_Hook(int ID, const char *Nick)
	{
		LuaManager->OnPlayerJoined(ID);
	}

	DLLEXPORT void SSGM_Player_Leave_Hook(int ID)
	{
		LuaManager->OnPlayerLeft(ID);
	}

	DLLEXPORT void SSGM_Level_Loaded_Hook()
	{
		cGameData *pGame = The_Game();
		if (NULL != pGame)
		{
			// Notify
			LuaManager->OnLevelLoaded(pGame->MapName);
		}
	}

	DLLEXPORT void SSGM_GameOver_Hook()
	{
		
	}

	DLLEXPORT void SSGM_Console_Output_Hook(const char *Output)
	{

	}

	//Hook into SSGM's DDE channel.
	//Return false to stop it from being passed to the console.
	DLLEXPORT bool SSGM_DDE_Hook(const char *DDE)
	{
		return true;
	}
}


